from awsglue.transforms import DropFields as DropFields, GlueTransform as GlueTransform
from typing import Any

class ApplyMapping(GlueTransform):
    def __call__(
        self,
        frame: Any,
        mappings: Any,
        case_sensitive: bool = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...



from awsglue.transforms import GlueTransform as GlueTransform
from typing import Any

class UnnestFrame(GlueTransform):
    def __call__(
        self,
        frame: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...



from awsglue.dynamicframe import (
    DynamicFrame as DynamicFrame,
    DynamicFrameCollection as DynamicFrameCollection,
)
from awsglue.utils import callsite as callsite, makeOptions as makeOptions
from typing import Any

class DataSink:
    def __init__(self, j_sink: Any, sql_ctx: Any) -> None: ...
    def setFormat(self, format: Any, **options: Any) -> None: ...
    def setAccumulableSize(self, size: Any) -> None: ...
    def setCatalogInfo(
        self, catalogDatabase: Any, catalogTableName: Any, catalogId: str = ...
    ) -> None: ...
    def writeFrame(self, dynamic_frame: Any, info: str = ...): ...
    def write(self, dynamic_frame_or_dfc: Any, info: str = ...): ...



from typing import Any

class ExecutionProperty:
    maxConcurrentRuns: Any = ...
    def __init__(self, maxConcurrentRuns: int = ...) -> None: ...
    def as_dict(self): ...

class Command:
    name: Any = ...
    scriptLocation: Any = ...
    def __init__(self, name: Any, scriptLocation: Any) -> None: ...
    def as_dict(self): ...

class Connections:
    connections: Any = ...
    def __init__(self, connections: Any = ...) -> None: ...
    def as_dict(self): ...

class Job:
    name: str = ...
    description: str = ...
    logUri: str = ...
    role: str = ...
    executionProperty: Any = ...
    command: Any = ...
    defaultArguments: Any = ...
    connections: Any = ...
    maxRetries: int = ...
    allocatedCapacity: int = ...
    createdOn: Any = ...
    lastModifiedOn: Any = ...
    def __init__(self) -> None: ...
    def as_dict(self): ...
    def as_job_create_dict(self): ...
    def as_job_update_dict(self): ...

class GlueJobUtils:
    s3: Any = ...
    glue: Any = ...
    def __init__(self, glue_context: Any) -> None: ...
    def get_jobs(self, nextToken: str = ...): ...
    def get_job(self, jobName: Any): ...
    def create_job(self, job: Any, file: str = ...): ...
    def update_job(self, job: Any, file: str = ...): ...
    def delete_job(self, jobName: Any): ...



from awsglue.transforms import GlueTransform as GlueTransform
from typing import Any

class ErrorsAsDynamicFrame(GlueTransform):
    def __call__(self, frame: Any): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...



from typing import Any, Optional

class DataFrameReader:
    def __init__(self, glue_context: Any) -> None: ...
    def from_catalog(
        self,
        database: Optional[Any] = ...,
        table_name: Optional[Any] = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
        push_down_predicate: str = ...,
        additional_options: Any = ...,
        catalog_id: Optional[Any] = ...,
        **kwargs: Any
    ): ...



from typing import Any

class GlueTransform:
    @classmethod
    def apply(cls, *args: Any, **kwargs: Any): ...
    @classmethod
    def name(cls): ...
    @classmethod
    def describeArgs(cls) -> None: ...
    @classmethod
    def describeReturn(cls) -> None: ...
    @classmethod
    def describeTransform(cls) -> None: ...
    @classmethod
    def describeErrors(cls) -> None: ...
    @classmethod
    def describe(cls): ...
    def __eq__(self, other: Any) -> Any: ...
    def __hash__(self) -> Any: ...



from awsglue.utils import iteritems as iteritems
from typing import Any

basestring = str
unicode = str

class DataType:
    properties: Any = ...
    def __init__(self, properties: Any = ...) -> None: ...
    def __eq__(self, other: Any) -> Any: ...
    def __hash__(self) -> Any: ...
    @classmethod
    def typeName(cls): ...
    def jsonValue(self): ...

class AtomicType(DataType):
    @classmethod
    def fromJsonValue(cls, json_value: Any): ...

class BinaryType(AtomicType): ...
class BooleanType(AtomicType): ...
class ByteType(AtomicType): ...
class DateType(AtomicType): ...

class DecimalType(AtomicType):
    precision: Any = ...
    scale: Any = ...
    def __init__(
        self, precision: int = ..., scale: int = ..., properties: Any = ...
    ) -> None: ...
    def jsonValue(self): ...

class DoubleType(AtomicType): ...

class EnumType(AtomicType):
    options: Any = ...
    def __init__(self, options: Any, properties: Any = ...) -> None: ...
    def jsonValue(self) -> None: ...

class FloatType(AtomicType): ...

class IntegerType(AtomicType):
    @classmethod
    def typeName(cls): ...

class LongType(AtomicType): ...
class NullType(AtomicType): ...
class ShortType(AtomicType): ...
class StringType(AtomicType): ...
class TimestampType(AtomicType): ...
class UnknownType(AtomicType): ...

class ArrayType(DataType):
    elementType: Any = ...
    def __init__(self, elementType: Any = ..., properties: Any = ...) -> None: ...
    def jsonValue(self): ...
    @classmethod
    def fromJsonValue(cls, json_value: Any): ...

class SetType(DataType):
    elementType: Any = ...
    def __init__(self, elementType: Any = ..., properties: Any = ...) -> None: ...
    def jsonValue(self): ...
    @classmethod
    def fromJsonValue(cls, json_value: Any): ...

class ChoiceType(DataType):
    choices: Any = ...
    def __init__(self, choices: Any = ..., properties: Any = ...) -> None: ...
    def add(self, new_choice: Any) -> None: ...
    def merge(self, new_choices: Any) -> None: ...
    def jsonValue(self): ...
    @classmethod
    def fromJsonValue(cls, json_value: Any): ...

class MapType(DataType):
    valueType: Any = ...
    def __init__(self, valueType: Any = ..., properties: Any = ...) -> None: ...
    def jsonValue(self): ...
    @classmethod
    def fromJsonValue(cls, json_value: Any): ...

class Field:
    name: Any = ...
    dataType: Any = ...
    properties: Any = ...
    def __init__(self, name: Any, dataType: Any, properties: Any = ...) -> None: ...
    def __eq__(self, other: Any) -> Any: ...
    def jsonValue(self): ...
    @classmethod
    def fromJsonValue(cls, json_value: Any): ...

class StructType(DataType):
    fields: Any = ...
    field_map: Any = ...
    def __init__(self, fields: Any = ..., properties: Any = ...) -> None: ...
    def __iter__(self) -> Any: ...
    def add(self, field: Any) -> None: ...
    def hasField(self, field: Any): ...
    def getField(self, field: Any): ...
    def jsonValue(self): ...
    @classmethod
    def fromJsonValue(cls, json_value: Any): ...

class EntityType(DataType):
    def __init__(self, entity: Any, base_type: Any, properties: Any) -> None: ...

def mergeDataTypes(s1: Any, s2: Any): ...

class DynamicRecord(dict):
    def __getattr__(self, attr: Any): ...
    def __setattr__(self, attr: Any, value: Any) -> None: ...



from awsglue.transforms import GlueTransform as GlueTransform
from typing import Any

class SelectFromCollection(GlueTransform):
    def __call__(self, dfc: Any, key: Any, transformation_ctx: str = ...): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class MapToCollection(GlueTransform):
    def __call__(self, dfc: Any, callable: Any, transformation_ctx: str = ...): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class FlatMap(GlueTransform):
    def __call__(
        self,
        dfc: Any,
        BaseTransform: Any,
        frame_name: Any,
        transformation_ctx: str = ...,
        **base_kwargs: Any
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...



import argparse
from .job import Job as Job
from typing import Any

def makeOptions(sc: Any, py_obj: Any): ...
def callsite(): ...
def iteritems(d: Any, **kwargs: Any): ...
def iterkeys(d: Any, **kwargs: Any): ...
def itervalues(d: Any, **kwargs: Any): ...

class GlueArgumentError(Exception): ...

class GlueArgumentParser(argparse.ArgumentParser):
    def error(self, msg: Any) -> None: ...

def getResolvedOptions(args: Any, options: Any): ...



from awsglue.utils import (
    callsite as callsite,
    iteritems as iteritems,
    itervalues as itervalues,
    makeOptions as makeOptions,
)
from typing import Any, Optional

long = int
basestring = str
unicode = str
imap = map
ifilter = filter

class ResolveOption:
    path: Any = ...
    action: Any = ...
    target: Any = ...
    def __init__(self, path: Any, action: Any, target: Optional[Any] = ...) -> None: ...

class DynamicFrame:
    glue_ctx: Any = ...
    name: Any = ...
    def __init__(self, jdf: Any, glue_ctx: Any, name: str = ...) -> None: ...
    def with_frame_schema(self, schema: Any): ...
    def schema(self): ...
    def show(self, num_rows: int = ...) -> None: ...
    def filter(
        self,
        f: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def mapPartitions(
        self,
        f: Any,
        preservesPartitioning: bool = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def map(
        self,
        f: Any,
        preservesPartitioning: bool = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def mapPartitionsWithIndex(
        self,
        f: Any,
        preservesPartitioning: bool = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def printSchema(self) -> None: ...
    def toDF(self, options: Optional[Any] = ...): ...
    @classmethod
    def fromDF(cls, dataframe: Any, glue_ctx: Any, name: Any): ...
    def unbox(
        self,
        path: Any,
        format: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
        **options: Any
    ): ...
    def drop_fields(
        self,
        paths: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def select_fields(
        self,
        paths: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def split_fields(
        self,
        paths: Any,
        name1: Any,
        name2: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def split_rows(
        self,
        comparison_dict: Any,
        name1: Any,
        name2: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def rename_field(
        self,
        oldName: Any,
        newName: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def write(
        self,
        connection_type: Any,
        connection_options: Any = ...,
        format: Optional[Any] = ...,
        format_options: Any = ...,
        accumulator_size: int = ...,
    ): ...
    def count(self): ...
    def spigot(
        self,
        path: Any,
        options: Any = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def join(
        self,
        paths1: Any,
        paths2: Any,
        frame2: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def unnest(
        self,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def relationalize(
        self,
        root_table_name: Any,
        staging_path: Any,
        options: Any = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def applyMapping(self, *args: Any, **kwargs: Any): ...
    def apply_mapping(
        self,
        mappings: Any,
        case_sensitive: bool = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def resolveChoice(
        self,
        specs: Optional[Any] = ...,
        choice: str = ...,
        database: Optional[Any] = ...,
        table_name: Optional[Any] = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
        catalog_id: Optional[Any] = ...,
    ): ...
    def mergeDynamicFrame(
        self,
        stage_dynamic_frame: Any,
        primary_keys: Any,
        transformation_ctx: str = ...,
        options: Any = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def union(
        self,
        other_frame: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def getNumPartitions(self): ...
    def repartition(
        self,
        num_partitions: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def coalesce(
        self,
        num_partitions: Any,
        shuffle: bool = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    def errorsAsDynamicFrame(self): ...
    def errorsCount(self): ...
    def stageErrorsCount(self): ...
    def assertErrorThreshold(self): ...

class DynamicFrameCollection:
    def __init__(self, dynamic_frames: Any, glue_ctx: Any) -> None: ...
    def __getitem__(self, key: Any): ...
    def __len__(self): ...
    def keys(self): ...
    def values(self): ...
    def select(self, key: Any, transformation_ctx: str = ...): ...
    def map(self, callable: Any, transformation_ctx: str = ...): ...
    def flatmap(self, f: Any, transformation_ctx: str = ...): ...

class DynamicFrameReader:
    def __init__(self, glue_context: Any) -> None: ...
    def from_rdd(
        self,
        data: Any,
        name: Any,
        schema: Optional[Any] = ...,
        sampleRatio: Optional[Any] = ...,
    ): ...
    def from_options(
        self,
        connection_type: Any,
        connection_options: Any = ...,
        format: Optional[Any] = ...,
        format_options: Any = ...,
        transformation_ctx: str = ...,
        push_down_predicate: str = ...,
        **kwargs: Any
    ): ...
    def from_catalog(
        self,
        database: Optional[Any] = ...,
        table_name: Optional[Any] = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
        push_down_predicate: str = ...,
        additional_options: Any = ...,
        catalog_id: Optional[Any] = ...,
        **kwargs: Any
    ): ...

class DynamicFrameWriter:
    def __init__(self, glue_context: Any) -> None: ...
    def from_options(
        self,
        frame: Any,
        connection_type: Any,
        connection_options: Any = ...,
        format: Optional[Any] = ...,
        format_options: Any = ...,
        transformation_ctx: str = ...,
    ): ...
    def from_catalog(
        self,
        frame: Any,
        database: Optional[Any] = ...,
        table_name: Optional[Any] = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
        additional_options: Any = ...,
        catalog_id: Optional[Any] = ...,
        **kwargs: Any
    ): ...
    def from_jdbc_conf(
        self,
        frame: Any,
        catalog_connection: Any,
        connection_options: Any = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
    ): ...



from awsglue.data_sink import DataSink as DataSink
from awsglue.data_source import DataSource as DataSource
from awsglue.dataframereader import DataFrameReader as DataFrameReader
from awsglue.dynamicframe import (
    DynamicFrame as DynamicFrame,
    DynamicFrameCollection as DynamicFrameCollection,
    DynamicFrameReader as DynamicFrameReader,
    DynamicFrameWriter as DynamicFrameWriter,
)
from awsglue.gluetypes import DataType as DataType
from awsglue.streaming_data_source import StreamingDataSource as StreamingDataSource
from awsglue.utils import callsite as callsite, makeOptions as makeOptions
from py4j.java_gateway import JavaClass as JavaClass
from pyspark.sql import SQLContext
from typing import Any, Optional

def register(sc: Any) -> None: ...

STREAMING_EXCEPTION_BACKOFF: int
STREAMING_EXCEPTION_INTERVAL: int
STREAMING_EXCEPTION_MAX_RETRIES_WITHIN_INTERVAL: int

class GlueContext(SQLContext):
    Spark_SQL_Formats: Any = ...
    create_dynamic_frame: Any = ...
    create_data_frame: Any = ...
    write_dynamic_frame: Any = ...
    spark_session: Any = ...
    def __init__(self, sparkContext: Any, **options: Any) -> None: ...
    def getSource(
        self,
        connection_type: Any,
        format: Optional[Any] = ...,
        transformation_ctx: str = ...,
        push_down_predicate: str = ...,
        **options: Any
    ): ...
    def get_catalog_schema_as_spark_schema(
        self,
        database: Optional[Any] = ...,
        table_name: Optional[Any] = ...,
        catalog_id: Optional[Any] = ...,
    ): ...
    def create_dynamic_frame_from_rdd(
        self,
        data: Any,
        name: Any,
        schema: Optional[Any] = ...,
        sample_ratio: Optional[Any] = ...,
        transformation_ctx: str = ...,
    ): ...
    def create_dynamic_frame_from_catalog(
        self,
        database: Optional[Any] = ...,
        table_name: Optional[Any] = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
        push_down_predicate: str = ...,
        additional_options: Any = ...,
        catalog_id: Optional[Any] = ...,
        **kwargs: Any
    ): ...
    def create_data_frame_from_catalog(
        self,
        database: Optional[Any] = ...,
        table_name: Optional[Any] = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
        push_down_predicate: str = ...,
        additional_options: Any = ...,
        catalog_id: Optional[Any] = ...,
        **kwargs: Any
    ): ...
    def create_dynamic_frame_from_options(
        self,
        connection_type: Any,
        connection_options: Any = ...,
        format: Optional[Any] = ...,
        format_options: Any = ...,
        transformation_ctx: str = ...,
        push_down_predicate: str = ...,
        **kwargs: Any
    ): ...
    def getSink(
        self,
        connection_type: Any,
        format: Optional[Any] = ...,
        transformation_ctx: str = ...,
        **options: Any
    ): ...
    def write_dynamic_frame_from_options(
        self,
        frame: Any,
        connection_type: Any,
        connection_options: Any = ...,
        format: Optional[Any] = ...,
        format_options: Any = ...,
        transformation_ctx: str = ...,
    ): ...
    def write_from_options(
        self,
        frame_or_dfc: Any,
        connection_type: Any,
        connection_options: Any = ...,
        format: Any = ...,
        format_options: Any = ...,
        transformation_ctx: str = ...,
        **kwargs: Any
    ): ...
    def write_dynamic_frame_from_catalog(
        self,
        frame: Any,
        database: Optional[Any] = ...,
        table_name: Optional[Any] = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
        additional_options: Any = ...,
        catalog_id: Optional[Any] = ...,
        **kwargs: Any
    ): ...
    def write_dynamic_frame_from_jdbc_conf(
        self,
        frame: Any,
        catalog_connection: Any,
        connection_options: Any = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
        catalog_id: Optional[Any] = ...,
    ) -> None: ...
    def write_from_jdbc_conf(
        self,
        frame_or_dfc: Any,
        catalog_connection: Any,
        connection_options: Any = ...,
        redshift_tmp_dir: str = ...,
        transformation_ctx: str = ...,
        catalog_id: Optional[Any] = ...,
    ): ...
    def convert_resolve_option(self, path: Any, action: Any, target: Any): ...
    def extract_jdbc_conf(
        self, connection_name: Any, catalog_id: Optional[Any] = ...
    ): ...
    def purge_table(
        self,
        database: Any,
        table_name: Any,
        options: Any = ...,
        transformation_ctx: str = ...,
        catalog_id: Optional[Any] = ...,
    ) -> None: ...
    def purge_s3_path(
        self, s3_path: Any, options: Any = ..., transformation_ctx: str = ...
    ) -> None: ...
    def transition_table(
        self,
        database: Any,
        table_name: Any,
        transition_to: Any,
        options: Any = ...,
        transformation_ctx: str = ...,
        catalog_id: Optional[Any] = ...,
    ) -> None: ...
    def transition_s3_path(
        self,
        s3_path: Any,
        transition_to: Any,
        options: Any = ...,
        transformation_ctx: str = ...,
    ) -> None: ...
    def get_logger(self): ...
    def currentTimeMillis(self): ...
    def forEachBatch(
        self, frame: Any, batch_function: Any, options: Any = ...
    ) -> None: ...
    def add_ingestion_time_columns(self, frame: Any, time_granularity: Any): ...
    def begin_transaction(self, read_only: Any): ...
    def commit_transaction(self, transaction_id: Any): ...
    def abort_transaction(self, transaction_id: Any): ...



from awsglue.utils import callsite as callsite, makeOptions as makeOptions
from typing import Any

class StreamingDataSource:
    name: Any = ...
    def __init__(self, j_source: Any, sql_ctx: Any, name: Any) -> None: ...
    def setFormat(self, format: Any, **options: Any) -> None: ...
    def getFrame(self): ...



from typing import Any

class Job:
    @classmethod
    def continuation_options(cls): ...
    @classmethod
    def job_bookmark_options(cls): ...
    @classmethod
    def job_bookmark_range_options(cls): ...
    @classmethod
    def id_params(cls): ...
    @classmethod
    def encryption_type_options(cls): ...
    @classmethod
    def data_lineage_options(cls): ...
    def __init__(self, glue_context: Any) -> None: ...
    def init(self, job_name: Any, args: Any = ...) -> None: ...
    def isInitialized(self): ...
    def commit(self) -> None: ...



from .apply_mapping import ApplyMapping as ApplyMapping
from .coalesce import Coalesce as Coalesce
from .collection_transforms import (
    FlatMap as FlatMap,
    MapToCollection as MapToCollection,
    SelectFromCollection as SelectFromCollection,
)
from .drop_nulls import DropNullFields as DropNullFields
from .dynamicframe_filter import Filter as Filter
from .dynamicframe_map import Map as Map
from .errors_as_dynamicframe import ErrorsAsDynamicFrame as ErrorsAsDynamicFrame
from .field_transforms import (
    DropFields as DropFields,
    Join as Join,
    RenameField as RenameField,
    SelectFields as SelectFields,
    Spigot as Spigot,
    SplitFields as SplitFields,
    SplitRows as SplitRows,
)
from .relationalize import Relationalize as Relationalize
from .repartition import Repartition as Repartition
from .resolve_choice import ResolveChoice as ResolveChoice
from .transform import GlueTransform as GlueTransform
from .unbox import Unbox as Unbox
from .union import Union as Union
from .unnest_frame import UnnestFrame as UnnestFrame
from typing import Any

ALL_TRANSFORMS: Any

def get_transforms(): ...
def get_transform(name: Any): ...
def describe_transform(name: Any): ...



from awsglue.transforms import GlueTransform as GlueTransform
from typing import Any, Optional

class RenameField(GlueTransform):
    def __call__(
        self,
        frame: Any,
        old_name: Any,
        new_name: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class DropFields(GlueTransform):
    def __call__(
        self,
        frame: Any,
        paths: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class SelectFields(GlueTransform):
    def __call__(
        self,
        frame: Any,
        paths: Any,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class SplitFields(GlueTransform):
    def __call__(
        self,
        frame: Any,
        paths: Any,
        name1: Optional[Any] = ...,
        name2: Optional[Any] = ...,
        transformation_ctx: str = ...,
        info: str = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class SplitRows(GlueTransform):
    def __call__(
        self,
        frame: Any,
        comparison_dict: Any,
        name1: str = ...,
        name2: str = ...,
        transformation_ctx: str = ...,
        info: Optional[Any] = ...,
        stageThreshold: int = ...,
        totalThreshold: int = ...,
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class Join(GlueTransform):
    def __call__(
        self,
        frame1: Any,
        frame2: Any,
        keys1: Any,
        keys2: Any,
        transformation_ctx: str = ...,
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...

class Spigot(GlueTransform):
    def __call__(
        self, frame: Any, path: Any, options: Any, transformation_ctx: str = ...
    ): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...



"""
Setup for awsglue type annotations.
"""


from setuptools import setup
import os
from pathlib import Path

src_path = "src"


def list_packages(src_path=src_path):
    for root, _, _ in os.walk(os.path.join(src_path, "awsglue")):
        yield ".".join(os.path.relpath(root, src_path).split(os.path.sep))


setup(
    name="awsglue-stubs",
    package_dir={"": src_path},
    version="0.0.1",
    description="A collection of the awsglue library stub files",
    long_description=((Path(__file__).parent / "README.md").read_text()),
    url="https://github.com/erickguan/awsglue-stubs",
    packages=list(list_packages()),
    package_data={"": ["*.pyi", "py.typed"]},
    install_requires=["pyspark-stubs==2.4.*"],
    classifiers=[
        "Programming Language :: Python :: 3 :: Only",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: Apache Software License",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Typing :: Typed",
    ],
)



from typing import Any

class ApplyMapping:
    @staticmethod
    def apply(frame: Any, mappings: Any): ...
    @classmethod
    def describeArgs(cls): ...
    @classmethod
    def describeTransform(cls): ...
    @classmethod
    def describeErrors(cls): ...
    @classmethod
    def describeReturn(cls): ...
